==> pdf-model-arlington-1.23.7-sources.jar: org/verapdf/model/alayer/AXRefStream.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
public interface AXRefStream extends AObject {
	













	public Boolean getcontainsAuthCode();

	public Boolean getisAuthCodeIndirect();

	public Boolean getAuthCodeHasTypeDictionary();

	public Boolean getcontainsDL();

	public Boolean getDLHasTypeInteger();

	public Long getDLIntegerValue();

	public Boolean getcontainsDecodeParms();

	public Boolean getisDecodeParmsIndirect();

	public Boolean getDecodeParmsHasTypeArray();

	public Boolean getDecodeParmsHasTypeDictionary();

	public Long getDecodeParmsArraySize();

	public Boolean getcontainsEncrypt();

	public Boolean getEncryptHasTypeDictionary();

	public Boolean getcontainsF();

	public Boolean getFHasTypeDictionary();

	public Boolean getFHasTypeString();

	public Boolean getcontainsFDecodeParms();

	public Boolean getFDecodeParmsHasTypeArray();

	public Boolean getFDecodeParmsHasTypeDictionary();

	public Long getFDecodeParmsArraySize();

	public Boolean getcontainsFFilter();

	public Boolean getFFilterHasTypeArray();

	public Boolean getFFilterHasTypeName();

	public String getFFilterNameValue();

	public Long getFFilterArraySize();

	public Boolean getcontainsFilter();

	public Boolean getisFilterIndirect();

	public Boolean getFilterHasTypeArray();

	public Boolean getFilterHasTypeName();

	public String getFilterNameValue();

	public Long getFilterArraySize();

	public String getFilterEntriesString();

	public Boolean getcontainsID();

	public Boolean getisentryIDIndirect();

	public Boolean getentryIDHasTypeArray();

	public Boolean getcontainsIndex();

	public Boolean getisIndexIndirect();

	public Boolean getIndexHasTypeArray();

	public Boolean getisIndexArraySortAscending2();

	public Long getIndexArraySize();

	public Boolean getcontainsInfo();

	public Boolean getisInfoIndirect();

	public Boolean getInfoHasTypeDictionary();

	public Boolean getcontainsLength();

	public Boolean getLengthHasTypeInteger();

	public Long getLengthIntegerValue();

	public Boolean getcontainsPrev();

	public Boolean getisPrevIndirect();

	public Boolean getPrevHasTypeInteger();

	public Long getPrevIntegerValue();

	public Boolean getcontainsRoot();

	public Boolean getisRootIndirect();

	public Boolean getRootHasTypeDictionary();

	public Boolean getcontainsSize();

	public Boolean getisSizeIndirect();

	public Boolean getSizeHasTypeInteger();

	public Long getSizeIntegerValue();

	public Boolean getcontainsType();

	public Boolean getisTypeIndirect();

	public Boolean getTypeHasTypeName();

	public String getTypeNameValue();

	public Boolean getcontainsW();

	public Boolean getisWIndirect();

	public Boolean getWHasTypeArray();

	public Long getEncryptVIntegerValue();
}

==> pdf-model-arlington-1.25.15-sources.jar: org/verapdf/model/alayer/AXRefStream.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AXRefStream extends AObject {
	













	/**
	*/
	public Boolean getcontainsAuthCode();

	/**
	*/
	public Boolean getisAuthCodeIndirect();

	/**
	*/
	public Boolean getAuthCodeHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsDL();

	/**
	*/
	public Boolean getDLHasTypeInteger();

	/**
	*/
	public Long getDLIntegerValue();

	/**
	*/
	public Boolean getcontainsDecodeParms();

	/**
	*/
	public Boolean getisDecodeParmsIndirect();

	/**
	*/
	public Boolean getDecodeParmsHasTypeArray();

	/**
	*/
	public Boolean getDecodeParmsHasTypeDictionary();

	/**
	*/
	public Long getDecodeParmsArraySize();

	/**
	*/
	public Boolean getcontainsEncrypt();

	/**
	*/
	public Boolean getEncryptHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public Boolean getFHasTypeDictionary();

	/**
	*/
	public Boolean getFHasTypeString();

	/**
	*/
	public Boolean getcontainsFDecodeParms();

	/**
	*/
	public Boolean getFDecodeParmsHasTypeArray();

	/**
	*/
	public Boolean getFDecodeParmsHasTypeDictionary();

	/**
	*/
	public Long getFDecodeParmsArraySize();

	/**
	*/
	public Boolean getcontainsFFilter();

	/**
	*/
	public Boolean getFFilterHasTypeArray();

	/**
	*/
	public Boolean getFFilterHasTypeName();

	/**
	*/
	public String getFFilterNameValue();

	/**
	*/
	public Long getFFilterArraySize();

	/**
	*/
	public Boolean getcontainsFilter();

	/**
	*/
	public Boolean getisFilterIndirect();

	/**
	*/
	public Boolean getFilterHasTypeArray();

	/**
	*/
	public Boolean getFilterHasTypeName();

	/**
	*/
	public String getFilterNameValue();

	/**
	*/
	public Long getFilterArraySize();

	/**
	*/
	public String getFilterEntriesString();

	/**
	*/
	public Boolean getcontainsID();

	/**
	*/
	public Boolean getisentryIDIndirect();

	/**
	*/
	public Boolean getentryIDHasTypeArray();

	/**
	*/
	public Boolean getcontainsIndex();

	/**
	*/
	public Boolean getisIndexIndirect();

	/**
	*/
	public Boolean getIndexHasTypeArray();

	/**
	*/
	public Boolean getisIndexArraySortAscending2();

	/**
	*/
	public Long getIndexArraySize();

	/**
	*/
	public Boolean getcontainsInfo();

	/**
	*/
	public Boolean getisInfoIndirect();

	/**
	*/
	public Boolean getInfoHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsLength();

	/**
	*/
	public Boolean getLengthHasTypeInteger();

	/**
	*/
	public Long getLengthIntegerValue();

	/**
	*/
	public Boolean getcontainsPrev();

	/**
	*/
	public Boolean getisPrevIndirect();

	/**
	*/
	public Boolean getPrevHasTypeInteger();

	/**
	*/
	public Long getPrevIntegerValue();

	/**
	*/
	public Boolean getcontainsRoot();

	/**
	*/
	public Boolean getisRootIndirect();

	/**
	*/
	public Boolean getRootHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsSize();

	/**
	*/
	public Boolean getisSizeIndirect();

	/**
	*/
	public Boolean getSizeHasTypeInteger();

	/**
	*/
	public Long getSizeIntegerValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getisTypeIndirect();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsW();

	/**
	*/
	public Boolean getisWIndirect();

	/**
	*/
	public Boolean getWHasTypeArray();

	/**
	*/
	public Long getEncryptVIntegerValue();

	/**
	*/
	public Boolean getEncryptVHasTypeInteger();

	/**
	*/
	public Boolean getcontainstrailerInfoModDate();

	/**
	*/
	public Boolean getcontainstrailerCatalogPieceInfo();

	/**
	*/
	public Boolean gethasExtensionISO_TS_32004();
}
